gchecky.model.shipping_in_order_adjustment_t

Package gchecky :: Module model :: Class shipping_in_order_adjustment_t |
[hide private]
[frames] | no frames]

# Class shipping_in_order_adjustment_t

source code

    object --+
             |
     gxml.Node --+
                 |
                shipping_in_order_adjustment_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| carrier_calculated_shipping_adjustment = `Node:PATH(carrier-cal`...``
| flat_rate_shipping_adjustment = `Node:PATH(flat-rate-shipping-a`...``
| merchant_calculated_shipping_adjustment = `Node:PATH(merchant-c`...``
| pickup_shipping_adjustment = `Node:PATH(pickup-shipping-adjustm`...``
| methods = `List:PATH():RE`...``
| _fields = ``{``'``carrier_calculated_shipping_adjustment``'``:` Node:PATH`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### carrier_calculated_shipping_adjustment Value:
      Node:PATH(carrier-calculated-shipping-adjustment):OPT:{ carrier_calcul
      ated_shipping_adjustment_t }

  ### flat_rate_shipping_adjustment Value:
      Node:PATH(flat-rate-shipping-adjustment):OPT:{ shipping_adjustment_t }

  ### merchant_calculated_shipping_adjustment Value:
      Node:PATH(merchant-calculated-shipping-adjustment):OPT:{ shipping_adju
      stment_t }

  ### pickup_shipping_adjustment Value:
      Node:PATH(pickup-shipping-adjustment):OPT:{ shipping_adjustment_t }

  ### methods Value:
      List:PATH():REQ:[
          String:PATH(method@name):REQ:EMPTY
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'carrier_calculated_shipping_adjustment': Node:PATH(carrier-calculate
      d-shipping-adjustment):OPT:{ carrier_calculated_shipping_adjustment_t
      },
       'flat_rate_shipping_adjustment': Node:PATH(flat-rate-shipping-adjustm
      ent):OPT:{ shipping_adjustment_t },
       'merchant_calculated_shipping_adjustment': Node:PATH(merchant-calcula
      ted-shipping-adjustment):OPT:{ shipping_adjustment_t },
       'methods': List:PATH():REQ:[
      ...